@@ -65,6 +65,8 @@ struct _AsComponentClass
  * @AS_COMPONENT_KIND_CODEC:		A multimedia codec
  * @AS_COMPONENT_KIND_INPUTMETHOD:	An input-method provider
  * @AS_COMPONENT_KIND_FIRMWARE:		Firmware
+ * @AS_COMPONENT_KIND_DRIVER:		A driver
+ * @AS_COMPONENT_KIND_LOCALIZATION:	Software localization (usually l10n resources)
  *
  * The type of an #AsComponent.
  **/
@@ -79,6 +81,8 @@ typedef enum  {
 	AS_COMPONENT_KIND_CODEC,
 	AS_COMPONENT_KIND_INPUTMETHOD,
 	AS_COMPONENT_KIND_FIRMWARE,
+	AS_COMPONENT_KIND_DRIVER,
+	AS_COMPONENT_KIND_LOCALIZATION,
 	/*< private >*/
 	AS_COMPONENT_KIND_LAST
 } AsComponentKind;
